@@ -1,13 +1,13 @@
 ### R code from vignette source 'RadOnc.Rnw'
 
 ###################################################
-### code chunk number 1: RadOnc.Rnw:51-52
+### code chunk number 1: RadOnc.Rnw:53-54
 ###################################################
 library(RadOnc)
 
 
 ###################################################
-### code chunk number 2: RadOnc.Rnw:54-57
+### code chunk number 2: RadOnc.Rnw:56-59
 ###################################################
 data.path <- system.file("extdata", package="RadOnc")
 initial.path <- getwd()
@@ -15,13 +15,13 @@ options(width=75)
 
 
 ###################################################
-### code chunk number 3: RadOnc.Rnw:77-78
+### code chunk number 3: RadOnc.Rnw:79-80
 ###################################################
 news(package="RadOnc")
 
 
 ###################################################
-### code chunk number 4: RadOnc.Rnw:90-94
+### code chunk number 4: RadOnc.Rnw:92-96
 ###################################################
 temp <- c(readLines(paste(data.path, 'Jane_Doe.dvh', sep='/'),n=50), "...", "...")
 for (i in 1:52) {
@@ -30,31 +30,31 @@ cat(temp[i], "\n")
 
 
 ###################################################
-### code chunk number 5: RadOnc.Rnw:97-98
+### code chunk number 5: RadOnc.Rnw:99-100
 ###################################################
 johndoe <- read.DVH(file=system.file("extdata/John_Doe.dvh", package="RadOnc"), type="aria10", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 6: RadOnc.Rnw:101-102 (eval = FALSE)
+### code chunk number 6: RadOnc.Rnw:103-104 (eval = FALSE)
 ###################################################
 ## read.DVH(file="Jane_Doe.dvh", type="aria10", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 7: RadOnc.Rnw:104-105
+### code chunk number 7: RadOnc.Rnw:106-107
 ###################################################
 janedoe <- read.DVH(file=system.file("extdata/Jane_Doe.dvh", package="RadOnc"), type="aria10", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 8: RadOnc.Rnw:109-110 (eval = FALSE)
+### code chunk number 8: RadOnc.Rnw:111-112 (eval = FALSE)
 ###################################################
 ## DVHs <- read.DVH(file=c("Jane_Doe.dvh", "John_Doe.dvh"), type="aria10")
 
 
 ###################################################
-### code chunk number 9: RadOnc.Rnw:112-114
+### code chunk number 9: RadOnc.Rnw:114-116
 ###################################################
 DVHs <- read.DVH(file=system.file(paste("extdata", c("Jane_Doe.dvh", "John_Doe.dvh"), sep="/"), package="RadOnc"), type="aria10")
 DVHs
@@ -68,20 +68,20 @@ plot(janedoe[c(3,6:7)],new=FALSE,col="red",lwd=1.25)
 
 
 ###################################################
-### code chunk number 11: RadOnc.Rnw:138-140
+### code chunk number 11: RadOnc.Rnw:140-142
 ###################################################
 janedoe[1:4]
 c(janedoe["PTV"], johndoe[c("CTV", "DUODENUM")])
 
 
 ###################################################
-### code chunk number 12: RadOnc.Rnw:142-143
+### code chunk number 12: RadOnc.Rnw:144-145
 ###################################################
 temp <- janedoe
 
 
 ###################################################
-### code chunk number 13: RadOnc.Rnw:145-148
+### code chunk number 13: RadOnc.Rnw:147-150
 ###################################################
 johndoe[["CTV"]]
 janedoe[[1]] <- johndoe[["CTV"]]
@@ -89,13 +89,13 @@ janedoe[1:4]
 
 
 ###################################################
-### code chunk number 14: RadOnc.Rnw:150-151
+### code chunk number 14: RadOnc.Rnw:152-153
 ###################################################
 janedoe <- temp
 
 
 ###################################################
-### code chunk number 15: RadOnc.Rnw:155-158
+### code chunk number 15: RadOnc.Rnw:157-160
 ###################################################
 janedoe["KIDNEY$"]
 janedoe[c(2,"IGHT.*")]
@@ -103,7 +103,16 @@ janedoe["(?i)liver"] ## (case insensitive matching) ##
 
 
 ###################################################
-### code chunk number 16: RadOnc.Rnw:163-167
+### code chunk number 16: RadOnc.Rnw:164-168
+###################################################
+subset(janedoe, structure=c("liver", "kidney"), ignore.case=TRUE)
+subset(janedoe, constraint="volume > 200(cc)")
+subset(janedoe, constraint="Dmean <= 500(cGy)")
+subset(janedoe, constraint="D2cc < 20(Gy)")
+
+
+###################################################
+### code chunk number 17: RadOnc.Rnw:173-177
 ###################################################
 names(janedoe)[1:4] <- c("A1", "B2", "C3", "D4")
 names(rev(janedoe[1:4]))
@@ -112,26 +121,20 @@ lapply(johndoe, function(DVH) { DVH[c("DMIN", "D50%", "DMAX", "V20%")] })
 
 
 ###################################################
-### code chunk number 17: RadOnc.Rnw:169-170
+### code chunk number 18: RadOnc.Rnw:179-180
 ###################################################
 janedoe <- temp
 
 
 ###################################################
-### code chunk number 18: RadOnc.Rnw:174-176
+### code chunk number 19: RadOnc.Rnw:184-186
 ###################################################
 janedoe[1:2]$patients
 janedoe[3:4]$ID
 
 
 ###################################################
-### code chunk number 19: RadOnc.Rnw:180-181
-###################################################
-getStructureList(DVHs, "(?i)Liver")
-
-
-###################################################
-### code chunk number 20: RadOnc.Rnw:188-192
+### code chunk number 20: RadOnc.Rnw:195-199
 ###################################################
 johndoe[["DUODENUM"]]["V20Gy"]
 johndoe[["DUODENUM"]]["D2.5%"]
@@ -140,33 +143,33 @@ johndoe[["DUODENUM"]]["D2.3286cc"]
 
 
 ###################################################
-### code chunk number 21: RadOnc.Rnw:195-197
+### code chunk number 21: RadOnc.Rnw:202-204
 ###################################################
 johndoe[["DUODENUM"]][c("V5%", "V20Gy", "D2.5%", "D2.3286cc", "Dmax")]
 johndoe[1:4]$"V10-20Gy,V20Gy,Dmax"
 
 
 ###################################################
-### code chunk number 22: RadOnc.Rnw:200-201
+### code chunk number 22: RadOnc.Rnw:207-208
 ###################################################
 johndoe[["DUODENUM"]][c("V5", "VGy", "volume", 2.5, "", "Dmax%")]
 
 
 ###################################################
-### code chunk number 23: RadOnc.Rnw:204-205
+### code chunk number 23: RadOnc.Rnw:211-212
 ###################################################
 johndoe[["LIVER"]][c("V10Gy(%)","D25%","D25%(Gy)")]
 
 
 ###################################################
-### code chunk number 24: RadOnc.Rnw:208-210
+### code chunk number 24: RadOnc.Rnw:215-217
 ###################################################
 johndoe[["LIVER"]][c("Dintegral","Dintegral(>0cGy)")]
 johndoe[["LIVER"]][c("Dintegral(<20Gy)","Dintegral(10-20Gy)")]
 
 
 ###################################################
-### code chunk number 25: RadOnc.Rnw:218-222
+### code chunk number 25: RadOnc.Rnw:225-229
 ###################################################
 gEUD(janedoe[1:3], 6:8)
 gEUD(janedoe[1:3], 1) == unlist(janedoe[1:3]$"Dmean")
@@ -175,7 +178,7 @@ gEUD(janedoe[1:3], -Inf) == unlist(janedoe[1:3]$"Dmin")
 
 
 ###################################################
-### code chunk number 26: RadOnc.Rnw:229-231
+### code chunk number 26: RadOnc.Rnw:236-238
 ###################################################
 LQE(c(4500, 5500, 6000), aB=3, fractions=c(300, 200))
 LQE(c(4500, 5500, 6000), aB=3, N=c(20, 36))
@@ -222,7 +225,7 @@ plot(janedoe[2:9], plot.type="b", volume="abs", dose="rel")
 
 
 ###################################################
-### code chunk number 32: RadOnc.Rnw:306-307 (eval = FALSE)
+### code chunk number 32: RadOnc.Rnw:313-314 (eval = FALSE)
 ###################################################
 ## plot(stomach, col="lightblue")
 
@@ -243,7 +246,7 @@ plot(mean(janedoe), new=FALSE, col="blue", lwd=2, lty="dashed")
 
 
 ###################################################
-### code chunk number 35: RadOnc.Rnw:337-340
+### code chunk number 35: RadOnc.Rnw:344-347
 ###################################################
 L.kidney <- janedoe[["LEFT_KIDNEY"]]
 R.kidney <- janedoe[["RIGHT_KIDNEY"]]
@@ -251,7 +254,7 @@ total.kidney <- sum(janedoe[c("LEFT_KIDNEY", "RIGHT_KIDNEY")])
 
 
 ###################################################
-### code chunk number 36: RadOnc.Rnw:342-348 (eval = FALSE)
+### code chunk number 36: RadOnc.Rnw:349-355 (eval = FALSE)
 ###################################################
 ## L.kidney <- janedoe[["LEFT_KIDNEY"]]
 ## R.kidney <- janedoe[["RIGHT_KIDNEY"]]
@@ -270,7 +273,7 @@ plot(R.kidney, new=FALSE, type="diff", volume="abs", col="blue")
 
 
 ###################################################
-### code chunk number 38: RadOnc.Rnw:364-367
+### code chunk number 38: RadOnc.Rnw:371-374
 ###################################################
 groupA <- janedoe[c("LIVER","LEFT_KIDNEY","RIGHT_KIDNEY","CORD")]
 groupB <- janedoe[c("CTV", "PTV")]
@@ -278,7 +281,7 @@ t.test(unlist(groupA$"V20Gy"), unlist(groupB$"V20Gy"))
 
 
 ###################################################
-### code chunk number 39: RadOnc.Rnw:372-374 (eval = FALSE)
+### code chunk number 39: RadOnc.Rnw:379-381 (eval = FALSE)
 ###################################################
 ## AvB <- t.test(groupA, groupB)
 ## plot(AvB$dose, AvB$p, type="l", log="y", xlab="Dose (cGy)", ylab="p-value")
@@ -295,32 +298,32 @@ text(2000,approx(AvB$dose, AvB$p, 2000)$y, col="red", labels="V20Gy (p=5.347e-05
 
 
 ###################################################
-### code chunk number 41: RadOnc.Rnw:399-400 (eval = FALSE)
+### code chunk number 41: RadOnc.Rnw:406-407 (eval = FALSE)
 ###################################################
 ## data <- read.DICOM.RT(path="<<DICOM directory>>", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 42: RadOnc.Rnw:404-405
+### code chunk number 42: RadOnc.Rnw:411-412
 ###################################################
 data("RadOnc")
 
 
 ###################################################
-### code chunk number 43: RadOnc.Rnw:412-414
+### code chunk number 43: RadOnc.Rnw:419-421
 ###################################################
 teeth[1:2]
 c(cord, mandible)
 
 
 ###################################################
-### code chunk number 44: RadOnc.Rnw:416-417
+### code chunk number 44: RadOnc.Rnw:423-424
 ###################################################
 temp <- teeth
 
 
 ###################################################
-### code chunk number 45: RadOnc.Rnw:419-422
+### code chunk number 45: RadOnc.Rnw:426-429
 ###################################################
 teeth[[1]]
 teeth[[1]] <- teeth[["Tooth #3"]]
@@ -328,19 +331,19 @@ teeth
 
 
 ###################################################
-### code chunk number 46: RadOnc.Rnw:424-425
+### code chunk number 46: RadOnc.Rnw:431-432
 ###################################################
 teeth <- temp
 
 
 ###################################################
-### code chunk number 47: RadOnc.Rnw:429-430
+### code chunk number 47: RadOnc.Rnw:436-437
 ###################################################
 teeth["Tooth.*"]
 
 
 ###################################################
-### code chunk number 48: RadOnc.Rnw:435-439
+### code chunk number 48: RadOnc.Rnw:442-446
 ###################################################
 names(teeth) <- c("Larry", "Curly", "Moe")
 names(rev(teeth[1:3]))
@@ -349,7 +352,7 @@ lapply(teeth, function(tooth) { range(tooth) })
 
 
 ###################################################
-### code chunk number 49: RadOnc.Rnw:441-442
+### code chunk number 49: RadOnc.Rnw:448-449
 ###################################################
 teeth <- temp
 
@@ -367,7 +370,7 @@ teeth <- temp
 
 
 ###################################################
-### code chunk number 52: RadOnc.Rnw:480-481 (eval = FALSE)
+### code chunk number 52: RadOnc.Rnw:487-488 (eval = FALSE)
 ###################################################
 ## compareStructures(teeth, method="axial", plot=TRUE)
 
@@ -379,31 +382,31 @@ compareStructures(teeth, method="axial", plot=TRUE, pixels=40)
 
 
 ###################################################
-### code chunk number 54: RadOnc.Rnw:493-494
+### code chunk number 54: RadOnc.Rnw:500-501
 ###################################################
 teeth <- teeth[c(1,3)]
 
 
 ###################################################
-### code chunk number 55: RadOnc.Rnw:496-497
+### code chunk number 55: RadOnc.Rnw:503-504
 ###################################################
 compareStructures(teeth, method="hausdorff", hausdorff.method="mean")
 
 
 ###################################################
-### code chunk number 56: RadOnc.Rnw:499-500
+### code chunk number 56: RadOnc.Rnw:506-507
 ###################################################
 teeth <- temp
 
 
 ###################################################
-### code chunk number 57: RadOnc.Rnw:504-505
+### code chunk number 57: RadOnc.Rnw:511-512
 ###################################################
 compareStructures(teeth, method="DSC")
 
 
 ###################################################
-### code chunk number 58: RadOnc.Rnw:536-537
+### code chunk number 58: RadOnc.Rnw:545-546
 ###################################################
 news(package="RadOnc")
 
